#coding:utf-8
from distutils.core import setup

setup(
    name = 'wxproject',
    version = '1.0',
    description= '测试发布',
    author ='wx',
    author_email='wx@faw.com.cn',
    py_modules =['mypackwx.mypyfile']
)